function W = W_Gauss(V, f_dist)

% Given a data set V (columns of V are positions in vector space) and
% distance function "f_dist", computes kernel matrix W by W =
% exp(-D/sigma^2).

%% Compute distance matrix
D = feval(f_dist, V);



%% Get standard deviation of distances.

% Initial vector of distances and index counter.
n = length(D);
dist = zeros(n*(n-1)/2,1);
count = 1;

% Extract distances from upper triangular entries of D.
for i=1:n
    for j = (i+1):n
        dist(count) = D(i,j);
        count = count + 1;
    end
end


%% Compute weight/kernel matrix W.

W = exp(-D.^2/(2*std(dist)^2));

W = W - diag(diag(W)); % Delete large entries from diagonal
