function [G,k] = planted_kdc(r,p)

% Generates a kernel matrix W for a  planted k-disjoint-clique subgraph
% indexed by the vector r (r1:rk) are clique sizes),
% obscured by random noise (edges added independently with probability p)
% and r(k+1) noise nodes. 

% Get total number of nodes.
N = sum(r);
% Number of planted cliques.
k = length(r) -1;

%% Initialize G:
G = rand(N); G = 0.5*(G + G');

% Add noise edge if Gij < p.
G = ceil(G - (1-p));

% Set diagonal entries to be all equal to 1.

%% Add planted cliques.

% Determine block structure of V wrt r.

c_beg = ones(k+1,1); % Initialize positions of start point of each planted clique.

% Set positions.
for i=2:k+1
    % Position is last position plus size of last clique.
    c_beg(i) = c_beg(i-1) + r(i-1); 
end

% Make all-ones blocks.
for i=1:k
    G(c_beg(i):(c_beg(i+1)-1), c_beg(i):(c_beg(i+1)-1)) = ones(r(i));
end

