function [W,k] = planted_wkdc(r,alpha, beta)

% Generates a kernel matrix W for a  planted k-disjoint-clique subgraph
% indexed by the vector r (r1:rk) are clique sizes),

% Get total number of nodes.
N = sum(r);
% Number of planted cliques.
k = length(r) -1;

%% Initialize W:
% Generate random matrix.
R = rand(N);
% Set off-diagonal blocks.
W = 2*beta*R;

%% Add planted cliques.

% Determine block structure of V wrt r.

c_beg = ones(k+1,1); % Initialize positions of start point of each planted clique.

% Set positions.
for i=2:k+1
    % Position is last position plus size of last clique.
    c_beg(i) = c_beg(i-1) + r(i-1); 
end

% Make diagonal-blocks blocks.
for i=1:k
    a = 1 - 2*(1-alpha);
    W(c_beg(i):(c_beg(i+1)-1), c_beg(i):(c_beg(i+1)-1)) = a + (1-a)*R(c_beg(i):(c_beg(i+1)-1), c_beg(i):(c_beg(i+1)-1));
end

%% Symmetrize W.
W = (W+W')/2;