function [V, Xref] = refine_extract2(X,k)

% Given output X from solving clique or kdc problem, refines the optimal
% solution and extracts characteristic vectors of optimal clique(s).

N = length(X);

%% Check which rows of X are active wrt row sum constraint.
% Discard any that aren't close to active.

%% Ignore entries of each row of X far from maximum value.
tol = 0.1;
R = floor(sum(X)' + tol);
Xtemp = X.*(R*R');

tol = 1/N;
Xref = ceil(Xtemp - tol);

%% Extract characteristic vectors of cliques using spectral decomposition of X.

% Get spectral decomp of Xref.
[Vtemp, L] = eig(Xref);

V = ceil(Vtemp(:, (N-k+1): N) -tol*ones(N,k)); % char vector is rescaled eigenvector.
