function [X, preptime, solvetime, At, b, val] = wkdc_sdpnal_1(W, k)

% Formulates weighted k-disjoint-clique in format for SDPNAL for given 
% weight matrix W and desired number of cliques k. 
% Solves and exports inputs At, b, blk.

%% Initialize data.

tic % Start timer.

% Get number of nodes.
n = length(W);

% Have m1=n row sum constraints.
m1 = n;
% Have m2=1 trace constraints.
m2 = 1;
% Have one nonnegativity constraint for each entry.
m3 = n*(n + 1)/2;
% Set number of constraints (n + 1 + #nonedges).
m = m1 + m2 + m3;


% Allocate temp var for constraints.
Atemp = cell(1,m);

% Semidefinite block 
blk{1,1} = 's';
blk{1,2} = n;
% Coefficient matrix for objective function is -W
C{1,1} = -W;

 
%% Block for  slack variables.

blk{2, 1} = 'l'; % block is nonnegative vector.
blk{2, 2} = m1 + m3; % have one entry for each row sum and nonnegativity constraint.

% Set At{2}: top left block is m1 by m1 identity, bottom right block is m3
% by m3 - identity.
At{2,1} = [speye(m1,m1), zeros(m1, m2 + m3); zeros(m3, m1 + m2), - speye(m3,m3)];

C{2,1} = spalloc(m-1,1,0);

    

% Right-hand side of constraints. % Sparsify!!
e = ones(m1,1);
b = sparse(1:m1+1, [e;1],  [e;k], m,1);


%% Define rows of At{1} corresponding to row sums.


for i = 1:m1    
     % Set all entries of the i-th row of the i-th constraint matrix equal
     % to 1.
     temp = sparse(i*e, 1:m1, 0.5*e, m1, m1);     
     Atemp{i} = temp + temp'; %- sparse(i, i, 0.5, m1, m1);
end

%% Define rows of At corresponding to trace contraints.

Atemp{m1 + 1} = speye(n); % Matrix for trace is identity.

 %% Define entries of At{1} corresponding to nonnedge constraints.
 
 count = m1 + m2 + 1;

  % For each upper triangular entry, want X_{ij} - slack_{i,j} = 0;
 for i=1:n
     
     for j = i:n                    
             Atemp{count} = spconvert([i,j,0.5; j,i,0.5; n,n, 0]);             
             count = count + 1;       
     end
 end

 
%% Convert Atemp to At.


% SDP block.
At{1,1} =svec(blk(1,:), Atemp)';
At{1,1} = At{1,1}{1};

preptime = toc; % Stop timer.

%% Write program input to file.

% Prefix writing to files.
% N = mat2str(n);
% K = mat2str(k);
% savefile = strcat('(N=', N,' k=', K,')-SDPNALinputs-W.mat');

% Write info
% save(savefile, 'At', 'b');

%% Call solver.
tic
[val, X] = sdpnal(blk, At, C, b);
X = X{1};
solvetime=toc;


